@@ -1,7 +1,7 @@
 // qxgeditOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -43,9 +43,8 @@ static const char *g_pszDefName = QT_TRANSLATE_NOOP("qxgeditOptionsForm", "(defa
 // qxgeditOptionsForm -- UI wrapper form.
 
 // Constructor.
-qxgeditOptionsForm::qxgeditOptionsForm (
-	QWidget *pParent, Qt::WindowFlags wflags )
-	: QDialog(pParent, wflags)
+qxgeditOptionsForm::qxgeditOptionsForm ( QWidget *pParent )
+	: QDialog(pParent)
 {
 	// Setup UI struct...
 	m_ui.setupUi(this);
@@ -61,8 +60,8 @@ qxgeditOptionsForm::qxgeditOptionsForm (
 	m_iMidiOutputsChanged = 0;
 
 	// Try to fix window geometry.
-	m_ui.MidiInputListView->setMaximumHeight(72);
-	m_ui.MidiOutputListView->setMaximumHeight(72);
+	m_ui.MidiInputListView->setMaximumHeight(96);
+	m_ui.MidiOutputListView->setMaximumHeight(96);
 
 	adjustSize();
 
@@ -215,44 +214,14 @@ void qxgeditOptionsForm::accept (void)
 		m_pOptions->fRandomizePercent = float(m_ui.RandomizePercentSpinBox->value());
 		m_pOptions->iBaseFontSize   = m_ui.BaseFontSizeComboBox->currentText().toInt();
 		// Custom options...
-		const QString sOldStyleTheme = m_pOptions->sStyleTheme;
 		if (m_ui.StyleThemeComboBox->currentIndex() > 0)
 			m_pOptions->sStyleTheme = m_ui.StyleThemeComboBox->currentText();
 		else
 			m_pOptions->sStyleTheme.clear();
-		const QString sOldColorTheme = m_pOptions->sColorTheme;
 		if (m_ui.ColorThemeComboBox->currentIndex() > 0)
 			m_pOptions->sColorTheme = m_ui.ColorThemeComboBox->currentText();
 		else
 			m_pOptions->sColorTheme.clear();
-		// Check whether restart is needed or whether
-		// custom options maybe set up immediately...
-		int iNeedRestart = 0;
-		if (m_pOptions->sStyleTheme != sOldStyleTheme) {
-			if (m_pOptions->sStyleTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QApplication::setStyle(
-					QStyleFactory::create(m_pOptions->sStyleTheme));
-			}
-		}
-		if (m_pOptions->sColorTheme != sOldColorTheme) {
-			if (m_pOptions->sColorTheme.isEmpty()) {
-				++iNeedRestart;
-			} else {
-				QPalette pal;
-				if (qxgeditPaletteForm::namedPalette(
-						&m_pOptions->settings(), m_pOptions->sColorTheme, pal))
-					QApplication::setPalette(pal);
-			}
-		}
-		// Show restart message if needed...
-		if (iNeedRestart > 0) {
-			QMessageBox::information(this,
-				tr("Information"),
-				tr("Some settings may be only effective\n"
-				"next time you start this application."));
-		}
 		// Reset dirty flag.
 		m_iDirtyCount = 0;
 	}
