@@ -1,7 +1,7 @@
 // qxgeditOptionsForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class qxgeditOptionsForm : public QDialog
 public:
 
 	// Constructor.
-	qxgeditOptionsForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qxgeditOptionsForm(QWidget *pParent = nullptr);
 	// Destructor.
 	~qxgeditOptionsForm();
 
